==> tvtime_0.9.12.orig.tar.gz: tvtime-0.9.12/src/tvtimeglyphs.h <==
/**
 * Copyright (C) 2002, 2003 Billy Biggs <vektor@dumbterm.net>.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/*      Constant                       UTF-8             Name                */
#define TVTIME_ICON_UPARROW            "\xe2\x96\xb4" /* Up Arrow            */
#define TVTIME_ICON_DOWNARROW          "\xe2\x96\xbc" /* Down Arrow          */
#define TVTIME_ICON_LEFTARROW          "\xe2\x97\x80" /* Left Arrow          */
#define TVTIME_ICON_RIGHTARROW         "\xe2\x96\xb6" /* Right Arrow         */
#define TVTIME_ICON_BACKARROW          "\xe2\x97\x84" /* Back Arrow          */
#define TVTIME_ICON_PLAINLEFTARROW     "\xe2\x86\x90" /* Plain Left Arrow    */
#define TVTIME_ICON_CONTRAST           "\xe2\x97\x90" /* Contrast            */
#define TVTIME_ICON_HUE                "\xe2\x97\xaf" /* Hue                 */
#define TVTIME_ICON_COLOUR             "\xe2\x98\xb0" /* Colour              */
#define TVTIME_ICON_BRIGHTNESS         "\xe2\x98\x80" /* Brightness          */
#define TVTIME_ICON_TVLOGO             "\xee\x80\x80" /* TV Logo             */
#define TVTIME_ICON_TIMELOGO01         "\xee\x80\x81" /* Time Logo 01        */
#define TVTIME_ICON_TIMELOGO02         "\xee\x80\x82" /* Time Logo 02        */
#define TVTIME_ICON_TIMELOGO03         "\xee\x80\x83" /* Time Logo 03        */
#define TVTIME_ICON_TIMELOGO04         "\xee\x80\x84" /* Time Logo 04        */
#define TVTIME_ICON_TIMELOGO05         "\xee\x80\x85" /* Time Logo 05        */
#define TVTIME_ICON_TIMELOGO06         "\xee\x80\x86" /* Time Logo 06        */
#define TVTIME_ICON_TIMELOGO07         "\xee\x80\x87" /* Time Logo 07        */
#define TVTIME_ICON_TIMELOGO08         "\xee\x80\x88" /* Time Logo 08        */
#define TVTIME_ICON_TIMELOGO09         "\xee\x80\x89" /* Time Logo 09        */
#define TVTIME_ICON_TIMELOGO10         "\xee\x80\x8a" /* Time Logo 10        */
#define TVTIME_ICON_TIMELOGO11         "\xee\x80\x8b" /* Time Logo 11        */
#define TVTIME_ICON_TIMELOGO12         "\xee\x80\x8c" /* Time Logo 12        */
#define TVTIME_ICON_TIMELOGO13         "\xee\x80\x8d" /* Time Logo 13        */
#define TVTIME_ICON_TIMELOGO14         "\xee\x80\x8e" /* Time Logo 14        */
#define TVTIME_ICON_TIMELOGO15         "\xee\x80\x8f" /* Time Logo 15        */
#define TVTIME_ICON_TIMELOGO16         "\xee\x80\x90" /* Time Logo 16        */
#define TVTIME_ICON_TIMELOGO17         "\xee\x80\x91" /* Time Logo 17        */
#define TVTIME_ICON_TIMELOGO18         "\xee\x80\x92" /* Time Logo 18        */
#define TVTIME_ICON_TIMELOGO19         "\xee\x80\x93" /* Time Logo 19        */
#define TVTIME_ICON_TIMELOGO20         "\xee\x80\x94" /* Time Logo 20        */
#define TVTIME_ICON_TIMELOGO21         "\xee\x80\x95" /* Time Logo 21        */
#define TVTIME_ICON_TIMELOGO22         "\xee\x80\x96" /* Time Logo 22        */
#define TVTIME_ICON_TIMELOGO23         "\xee\x80\x97" /* Time Logo 23        */
#define TVTIME_ICON_TIMELOGO24         "\xee\x80\x98" /* Time Logo 24        */
#define TVTIME_ICON_TIMELOGO25         "\xee\x80\x99" /* Time Logo 25        */
#define TVTIME_ICON_TVPGICON           "\xee\x80\x9a" /* TV|PG Icon          */
#define TVTIME_ICON_INPUTCONF          "\xee\x80\x9b" /* Input Config        */
#define TVTIME_ICON_RESTART            "\xee\x80\x9c" /* Restart             */
#define TVTIME_ICON_STATIONMANAGEMENT  "\xee\x80\x9d" /* Station Management  */
#define TVTIME_ICON_PICTURESETTINGS    "\xee\x80\x9e" /* Picture Settings    */
#define TVTIME_ICON_VIDEOPROCESSING    "\xee\x80\x9f" /* Video Processing    */
#define TVTIME_ICON_EXIT               "\xee\x80\xa0" /* Exit                */
#define TVTIME_ICON_DEINTERLACERCONF   "\xee\x80\xa1" /* Deinterlacer Conf.  */
#define TVTIME_ICON_STOPWATCH          "\xee\x80\xa2" /* Stopwatch           */
#define TVTIME_ICON_SCANFORSTATIONS    "\xee\x80\xa3" /* Scan for stations   */
#define TVTIME_ICON_RADIOOFF           "\xee\x80\xa4" /* Radio off           */
#define TVTIME_ICON_RADIOON            "\xee\x80\xa5" /* Radio on            */
#define TVTIME_ICON_DEVICESETUP        "\xee\x80\xa6" /* Device setup        */
#define TVTIME_ICON_PLUSBUTTON         "\xee\x80\xa8" /* Plus Button         */
#define TVTIME_ICON_MINUSBUTTON        "\xee\x80\xa9" /* Minus Button        */
#define TVTIME_ICON_FAVORITESICON      "\xee\x80\xaa" /* Favorites Icon      */
#define TVTIME_ICON_DEINTERLACERDESC   "\xee\x80\xab" /* Deinterlacer Desc.  */
#define TVTIME_ICON_ATTEMPTEDFRAMERATE "\xee\x80\xac" /* Attempted Framerate */
#define TVTIME_ICON_TELEVISIONSTANDARD "\xee\x80\xad" /* Television Standard */
#define TVTIME_ICON_INPUTFILTERS       "\xee\x80\xae" /* Input Filters       */
#define TVTIME_ICON_RENUMBERCHANNEL    "\xee\x80\xaf" /* Renumber Channel    */
#define TVTIME_ICON_FINETUNECHANNEL    "\xee\x80\xb0" /* Finetune Channel    */
#define TVTIME_ICON_OVERSCANSETTING    "\xee\x80\xb1" /* Overscan Setting    */
#define TVTIME_ICON_GENERALTOGGLEON    "\xee\x80\xb7" /* General Toggle On   */
#define TVTIME_ICON_GENERALTOGGLEOFF   "\xee\x80\xb8" /* General Toggle Off  */
#define TVTIME_ICON_OUTPUTCONF         "\xee\x80\xb9" /* Output Config.      */
#define TVTIME_ICON_FREQUENCYTABLESEL  "\xee\x80\xba" /* Freq. Table Sel.    */
#define TVTIME_ICON_CLOSEDCAPTIONICON  "\xee\x80\xb6" /* Closed Caption Icon */
#define TVTIME_ICON_VIDEOINPUT         "\xee\x80\xbb" /* Video Input         */
#define TVTIME_ICON_SAVEPICTUREGLOBAL  "\xee\x80\xbd" /* Save curr. picture  */
                                                      /* settings (global)   */
#define TVTIME_ICON_SAVEPICTURECHANNEL "\xee\x80\xbc" /* Save current pic.   */
                                                      /* settings (channel)  */
#define TVTIME_ICON_RESETTODEFAULTS    "\xee\x80\xbe" /* Reset to Defaults   */
#define TVTIME_ICON_CHANGENTSCMODE     "\xee\x80\xbf" /* Change NTSC Mode    */
#define TVTIME_ICON_APPLYMATTE         "\xee\x81\x80" /* Apply Matte         */
#define TVTIME_ICON_SETFSPOS           "\xee\x80\xb5" /* Fullscreen Position */
#define TVTIME_ICON_INPUTWIDTH         "\xee\x81\x81" /* Input width         */
#define TVTIME_ICON_ALLCHANNELSACTIVE  "\xee\x80\xa7" /* Set All Active      */

==> tvtime_1.0.11.orig.tar.gz: tvtime-1.0.11/src/tvtimeglyphs.h <==
/**
 * Copyright (C) 2002, 2003 Billy Biggs <vektor@dumbterm.net>.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/*      Constant                       UTF-8             Name                */
#define TVTIME_ICON_UPARROW            "\xe2\x96\xb4" /* Up Arrow            */
#define TVTIME_ICON_DOWNARROW          "\xe2\x96\xbc" /* Down Arrow          */
#define TVTIME_ICON_LEFTARROW          "\xe2\x97\x80" /* Left Arrow          */
#define TVTIME_ICON_RIGHTARROW         "\xe2\x96\xb6" /* Right Arrow         */
#define TVTIME_ICON_BACKARROW          "\xe2\x97\x84" /* Back Arrow          */
#define TVTIME_ICON_PLAINLEFTARROW     "\xe2\x86\x90" /* Plain Left Arrow    */
#define TVTIME_ICON_CONTRAST           "\xe2\x97\x90" /* Contrast            */
#define TVTIME_ICON_HUE                "\xe2\x97\xaf" /* Hue                 */
#define TVTIME_ICON_SATURATION         "\xe2\x98\xb0" /* Saturation          */
#define TVTIME_ICON_BRIGHTNESS         "\xe2\x98\x80" /* Brightness          */
#define TVTIME_ICON_TVLOGO             "\xee\x80\x80" /* TV Logo             */
#define TVTIME_ICON_TIMELOGO01         "\xee\x80\x81" /* Time Logo 01        */
#define TVTIME_ICON_TIMELOGO02         "\xee\x80\x82" /* Time Logo 02        */
#define TVTIME_ICON_TIMELOGO03         "\xee\x80\x83" /* Time Logo 03        */
#define TVTIME_ICON_TIMELOGO04         "\xee\x80\x84" /* Time Logo 04        */
#define TVTIME_ICON_TIMELOGO05         "\xee\x80\x85" /* Time Logo 05        */
#define TVTIME_ICON_TIMELOGO06         "\xee\x80\x86" /* Time Logo 06        */
#define TVTIME_ICON_TIMELOGO07         "\xee\x80\x87" /* Time Logo 07        */
#define TVTIME_ICON_TIMELOGO08         "\xee\x80\x88" /* Time Logo 08        */
#define TVTIME_ICON_TIMELOGO09         "\xee\x80\x89" /* Time Logo 09        */
#define TVTIME_ICON_TIMELOGO10         "\xee\x80\x8a" /* Time Logo 10        */
#define TVTIME_ICON_TIMELOGO11         "\xee\x80\x8b" /* Time Logo 11        */
#define TVTIME_ICON_TIMELOGO12         "\xee\x80\x8c" /* Time Logo 12        */
#define TVTIME_ICON_TIMELOGO13         "\xee\x80\x8d" /* Time Logo 13        */
#define TVTIME_ICON_TIMELOGO14         "\xee\x80\x8e" /* Time Logo 14        */
#define TVTIME_ICON_TIMELOGO15         "\xee\x80\x8f" /* Time Logo 15        */
#define TVTIME_ICON_TIMELOGO16         "\xee\x80\x90" /* Time Logo 16        */
#define TVTIME_ICON_TIMELOGO17         "\xee\x80\x91" /* Time Logo 17        */
#define TVTIME_ICON_TIMELOGO18         "\xee\x80\x92" /* Time Logo 18        */
#define TVTIME_ICON_TIMELOGO19         "\xee\x80\x93" /* Time Logo 19        */
#define TVTIME_ICON_TIMELOGO20         "\xee\x80\x94" /* Time Logo 20        */
#define TVTIME_ICON_TIMELOGO21         "\xee\x80\x95" /* Time Logo 21        */
#define TVTIME_ICON_TIMELOGO22         "\xee\x80\x96" /* Time Logo 22        */
#define TVTIME_ICON_TIMELOGO23         "\xee\x80\x97" /* Time Logo 23        */
#define TVTIME_ICON_TIMELOGO24         "\xee\x80\x98" /* Time Logo 24        */
#define TVTIME_ICON_TIMELOGO25         "\xee\x80\x99" /* Time Logo 25        */
#define TVTIME_ICON_TVPGICON           "\xee\x80\x9a" /* TV|PG Icon          */
#define TVTIME_ICON_INPUTCONF          "\xee\x80\x9b" /* Input Config        */
#define TVTIME_ICON_RESTART            "\xee\x80\x9c" /* Restart             */
#define TVTIME_ICON_STATIONMANAGEMENT  "\xee\x80\x9d" /* Station Management  */
#define TVTIME_ICON_PICTURESETTINGS    "\xee\x80\x9e" /* Picture Settings    */
#define TVTIME_ICON_VIDEOPROCESSING    "\xee\x80\x9f" /* Video Processing    */
#define TVTIME_ICON_EXIT               "\xee\x80\xa0" /* Exit                */
#define TVTIME_ICON_DEINTERLACERCONF   "\xee\x80\xa1" /* Deinterlacer Conf.  */
#define TVTIME_ICON_STOPWATCH          "\xee\x80\xa2" /* Stopwatch           */
#define TVTIME_ICON_SCANFORSTATIONS    "\xee\x80\xa3" /* Scan for stations   */
#define TVTIME_ICON_RADIOOFF           "\xee\x80\xa4" /* Radio off           */
#define TVTIME_ICON_RADIOON            "\xee\x80\xa5" /* Radio on            */
#define TVTIME_ICON_DEVICESETUP        "\xee\x80\xa6" /* Device setup        */
#define TVTIME_ICON_PLUSBUTTON         "\xee\x80\xa8" /* Plus Button         */
#define TVTIME_ICON_MINUSBUTTON        "\xee\x80\xa9" /* Minus Button        */
#define TVTIME_ICON_FAVORITESICON      "\xee\x80\xaa" /* Favorites Icon      */
#define TVTIME_ICON_DEINTERLACERDESC   "\xee\x80\xab" /* Deinterlacer Desc.  */
#define TVTIME_ICON_ATTEMPTEDFRAMERATE "\xee\x80\xac" /* Attempted Framerate */
#define TVTIME_ICON_TELEVISIONSTANDARD "\xee\x80\xad" /* Television Standard */
#define TVTIME_ICON_INPUTFILTERS       "\xee\x80\xae" /* Input Filters       */
#define TVTIME_ICON_RENUMBERCHANNEL    "\xee\x80\xaf" /* Renumber Channel    */
#define TVTIME_ICON_FINETUNECHANNEL    "\xee\x80\xb0" /* Finetune Channel    */
#define TVTIME_ICON_OVERSCANSETTING    "\xee\x80\xb1" /* Overscan Setting    */
#define TVTIME_ICON_GENERALTOGGLEON    "\xee\x80\xb7" /* General Toggle On   */
#define TVTIME_ICON_GENERALTOGGLEOFF   "\xee\x80\xb8" /* General Toggle Off  */
#define TVTIME_ICON_OUTPUTCONF         "\xee\x80\xb9" /* Output Config.      */
#define TVTIME_ICON_FREQUENCYTABLESEL  "\xee\x80\xba" /* Freq. Table Sel.    */
#define TVTIME_ICON_CLOSEDCAPTIONICON  "\xee\x80\xb6" /* Closed Caption Icon */
#define TVTIME_ICON_VIDEOINPUT         "\xee\x80\xbb" /* Video Input         */
#define TVTIME_ICON_SAVEPICTUREGLOBAL  "\xee\x80\xbd" /* Save curr. picture  */
                                                      /* settings (global)   */
#define TVTIME_ICON_SAVEPICTURECHANNEL "\xee\x80\xbc" /* Save current pic.   */
                                                      /* settings (channel)  */
#define TVTIME_ICON_RESETTODEFAULTS    "\xee\x80\xbe" /* Reset to Defaults   */
#define TVTIME_ICON_CHANGENTSCMODE     "\xee\x80\xbf" /* Change NTSC Mode    */
#define TVTIME_ICON_APPLYMATTE         "\xee\x81\x80" /* Apply Matte         */
#define TVTIME_ICON_SETFSPOS           "\xee\x80\xb5" /* Fullscreen Position */
#define TVTIME_ICON_INPUTWIDTH         "\xee\x81\x81" /* Input width         */
#define TVTIME_ICON_ALLCHANNELSACTIVE  "\xee\x80\xa7" /* Set All Active      */
